==> edc_consent-0.2.43-py3-none-any.whl: edc_consent/field_mixins/vulnerability_fields_mixin.py <==
from django.conf import settings
from django.db import models
from django.utils.safestring import mark_safe
from django_crypto_fields.fields import LastnameField
from django_crypto_fields.models import CryptoMixin
from edc_constants.choices import YES_NO

from ..validators import eligible_if_no, FullNameValidator


class VulnerabilityFieldsMixin(CryptoMixin, models.Model):

    is_incarcerated = models.CharField(
        verbose_name="Is the participant under involuntary incarceration?",
        max_length=3,
        choices=YES_NO,
        validators=[eligible_if_no],
        null=True,
        help_text="( if 'Yes' STOP participant cannot be consented )",
    )

    is_literate = models.CharField(
        verbose_name="Is the participant literate?",
        max_length=3,
        choices=YES_NO,
        help_text=(
            "If 'No' provide witness's name on this "
            "form and signature on the paper document."
        ),
    )

    witness_name = LastnameField(
        verbose_name="Witness's last and first name",
        validators=[FullNameValidator()],
        blank=True,
        null=True,
        help_text=mark_safe(
            "Required only if participant is illiterate.<br>"
            "Format is 'LASTNAME, FIRSTNAME'. "
            "All uppercase separated by a comma."
        ),
    )

    language = models.CharField(
        verbose_name="Language of consent",
        max_length=25,
        choices=settings.LANGUAGES,
        help_text=(
            "The language used for the consent process will "
            "also be used during data collection."
        ),
    )

    class Meta:
        abstract = True

==> edc_consent-0.3.15-py3-none-any.whl: edc_consent/field_mixins/vulnerability_fields_mixin.py <==
from django.conf import settings
from django.db import models
from django.utils.safestring import mark_safe
from django_crypto_fields.fields import LastnameField
from django_crypto_fields.models import CryptoMixin
from edc_constants.choices import YES_NO

from ..validators import FullNameValidator, eligible_if_no


class VulnerabilityFieldsMixin(CryptoMixin, models.Model):

    is_incarcerated = models.CharField(
        verbose_name="Is the participant under involuntary incarceration?",
        max_length=3,
        choices=YES_NO,
        validators=[eligible_if_no],
        null=True,
        help_text="( if 'Yes' STOP participant cannot be consented )",
    )

    is_literate = models.CharField(
        verbose_name="Is the participant literate?",
        max_length=3,
        choices=YES_NO,
        help_text=(
            "If 'No' provide witness's name on this "
            "form and signature on the paper document."
        ),
    )

    witness_name = LastnameField(
        verbose_name="Witness's last and first name",
        validators=[FullNameValidator()],
        blank=True,
        null=True,
        help_text=mark_safe(
            "Required only if participant is illiterate.<br>"
            "Format is 'LASTNAME, FIRSTNAME'. "
            "All uppercase separated by a comma."
        ),
    )

    language = models.CharField(
        verbose_name="Language of consent",
        max_length=25,
        choices=settings.LANGUAGES,
        help_text=(
            "The language used for the consent process will "
            "also be used during data collection."
        ),
    )

    class Meta:
        abstract = True
